@@ -110,7 +110,9 @@ class AnalysisForm(forms.Form):
 
     def get_wanted_fields(self):
         form = self.cleaned_data
-        wanted_fields =['Word','Token','Vowel','PrevCons','FollCons','Speaker']
+        wanted_fields =['Word','Token','Speaker']
+        if form['measure'] != 'N':
+            wanted_fields.extend(['Vowel','PrevCons','FollCons'])
         if form['segmentalDurations']:
             wanted_fields.extend(['VowDur','OtherDur'])
         if form['speakingRates']:
